@@ -70,6 +70,17 @@ class Connection(ABCConnection):
         finally:
             cursor.close()
 
+    async def _fetchmany(self, size: int, query: str, *params, **options) -> t.List[t.Mapping]:
+        cursor = await self.conn.cursor()
+        try:
+            await cursor.execute(query, params)
+            rows = await cursor.fetchmany(size)
+            desc = cursor.description
+            return [Record(row, desc) for row in rows]
+
+        finally:
+            cursor.close()
+
     async def _fetchone(self, query: str, *params, **options) -> t.Optional[t.Mapping]:
         cursor = await self.conn.cursor()
         try:
@@ -89,6 +100,19 @@ class Connection(ABCConnection):
             res = res[column]
         return res
 
+    async def _iterate(self, query: str, *params, **options) -> t.AsyncIterator[Record]:
+        cursor = await self.conn.cursor()
+        try:
+            await cursor.execute(query, params)
+            while True:
+                row = await cursor.fetchone()
+                if row is None:
+                    break
+                yield Record(row, cursor.description)
+
+        finally:
+            cursor.close()
+
 
 class Backend(ABCDatabaseBackend):
 
